@@ -163,19 +163,22 @@ static void get_error_rate(const char *str, error_t *e)
 }
 
 int32_t
-dwgsim_opt_is_int(char *optarg)
+dwgsim_opt_is_int(char *optarg, int32_t neg_ok)
 {
   int32_t i;
-  for(i=0;i<strlen(optarg);i++) {
+  int32_t len = strlen(optarg);
+  if (len == 0) return 0;
+  if ('+' != optarg[0] && (neg_ok == 0 || '-' != optarg[0]) && !isdigit(optarg[0])) return 0;
+  for(i=1;i<len;i++) {
       if(!isdigit(optarg[i])) return 0;
   }
   return 1;
 }
 
 int32_t
-dwgsim_atoi(char *optarg, char flag)
+dwgsim_atoi(char *optarg, char flag, int32_t neg_ok)
 {
-  if(0 == dwgsim_opt_is_int(optarg)) {
+  if(0 == dwgsim_opt_is_int(optarg, neg_ok)) {
       fprintf(stderr, "Error: command line option -%c is not a number [%s]\n", flag, optarg);
       exit(1);
   }
@@ -192,22 +195,22 @@ dwgsim_opt_parse(dwgsim_opt_t *opt, int argc, char *argv[])
   while ((c = getopt(argc, argv, "id:s:N:C:1:2:e:E:r:F:R:X:I:c:S:n:y:BHf:z:Mm:b:v:x:P:q:Q:h")) >= 0) {
       switch (c) {
         case 'i': opt->is_inner = 1; break;
-        case 'd': opt->dist = dwgsim_atoi(optarg, 'd'); break;
+        case 'd': opt->dist = dwgsim_atoi(optarg, 'd', 0); break;
         case 's': opt->std_dev = atof(optarg); break;
-        case 'N': opt->N = dwgsim_atoi(optarg, 'N'); opt->C = -1; break;
+        case 'N': opt->N = dwgsim_atoi(optarg, 'N', 1); opt->C = -1; break;
         case 'C': opt->C = atof(optarg); opt->N = -1; break;
-        case '1': opt->length[0] = dwgsim_atoi(optarg, '1'); break;
-        case '2': opt->length[1] = dwgsim_atoi(optarg, '2'); break;
+        case '1': opt->length[0] = dwgsim_atoi(optarg, '1', 0); break;
+        case '2': opt->length[1] = dwgsim_atoi(optarg, '2', 0); break;
         case 'e': get_error_rate(optarg, &opt->e[0]); break;
         case 'E': get_error_rate(optarg, &opt->e[1]); break;
         case 'r': opt->mut_rate = atof(optarg); break;
         case 'F': opt->mut_freq = atof(optarg); break;
         case 'R': opt->indel_frac = atof(optarg); break;
         case 'X': opt->indel_extend = atof(optarg); break;
-        case 'I': opt->indel_min = dwgsim_atoi(optarg, 'I'); break;
-        case 'c': opt->data_type = dwgsim_atoi(optarg, 'c'); break;
-        case 'S': opt->strandedness = dwgsim_atoi(optarg, 'S'); break;
-        case 'n': opt->max_n = dwgsim_atoi(optarg, 'n'); break;
+        case 'I': opt->indel_min = dwgsim_atoi(optarg, 'I', 0); break;
+        case 'c': opt->data_type = dwgsim_atoi(optarg, 'c', 0); break;
+        case 'S': opt->strandedness = dwgsim_atoi(optarg, 'S', 0); break;
+        case 'n': opt->max_n = dwgsim_atoi(optarg, 'n', 0); break;
         case 'y': opt->rand_read = atof(optarg); break;
         case 'f': 
                   if(NULL != opt->flow_order) free(opt->flow_order);
@@ -216,7 +219,7 @@ dwgsim_opt_parse(dwgsim_opt_t *opt, int argc, char *argv[])
         case 'B': opt->use_base_error = 1; break;
         case 'H': opt->is_hap = 1; break;
         case 'h': return 0;
-        case 'z': opt->seed = dwgsim_atoi(optarg, 'n'); break;
+        case 'z': opt->seed = dwgsim_atoi(optarg, 'z', 1); break;
         case 'M': opt->muts_only = 1; break;
         case 'm': free(opt->fn_muts_input); opt->fn_muts_input = strdup(optarg); opt->fn_muts_input_type = MUT_INPUT_TXT; muts_input_type |= 0x1; break;
         case 'b': free(opt->fn_muts_input); opt->fn_muts_input = strdup(optarg); opt->fn_muts_input_type = MUT_INPUT_BED; muts_input_type |= 0x2; break;
@@ -292,7 +295,19 @@ dwgsim_opt_parse(dwgsim_opt_t *opt, int argc, char *argv[])
   if(NULL != opt->read_prefix) {
       fprintf(stderr, "Warning: remember to use the -P option with dwgsim_eval\n");
   }
-  
+
+  if(0 < opt->length[1]){ //paired end / mate pair
+    int s = opt->length[0] + opt->length[1] + opt->is_inner;
+    double r = (s-opt->dist)*1.0/opt->std_dev;
+    if(r>6){
+      fprintf(stderr, "Error: command line option -d is too small for the read length (%d)\n",opt->dist);
+      return 0;
+    }
+    if(r>4){
+      fprintf(stderr, "Warning: command line option -d is small for the read length (%d). Generation speed could be affected.\n",opt->dist);
+    }
+  }
+
   switch(muts_input_type) {
     case 0x0:
     case 0x1:
